@@ -19,7 +19,7 @@ else
 	LONGREV="`hg --repository "${TMP}" log -r tip --template '{node}\n'`"
 	TARNAME="${DIR}_${REV}.orig.tar"
 	echo "${LONGREV}"
-	EXCLUDE="--exclude ${TMP}/.hgtags --exclude ${TMP}/.hg_archival.txt --exclude ${TMP}/.hgignore --exclude ${TMP}/roms"
+	EXCLUDE="--exclude ${TMP}/.hgtags --exclude ${TMP}/.hg_archival.txt --exclude ${TMP}/.hgignore"
 	hg --repository "${TMP}" archive --no-decode --type tar --prefix "${DIR}-${REV}/" ${EXCLUDE} -r tip "${TARNAME}"
 	gzip -n -f "${TARNAME}"
 	rm -rf "${TMP}"
